Method: Word.process
- Defined in:
- lib/word_play.rb
.process(text) ⇒ Object
In order to check for *Anagram* convert all the letters into lowercase, split them into letters, sort them and join them to form a string!
50 51 52 |
# File 'lib/word_play.rb', line 50 def process(text) text.downcase.split('').sort.join end |